#pragma once

using namespace std ;

#include <complex>

#include <set>

#include "molecule.h"

/** convert Kelvin to Celsius
*/
#define KELVIN2CELS(k) ((k)-273.15)

/** convert mm Hg to Pascal
*/
#define MMHG2PA(q) (133.322*(q))

/** convert Pascal to mm Hg
*/
#define PA2MMHG(p) ((p)/133.322)

#include "transition.h"

/* 1-base definition of the indices of the atoms and molecules not part of the HITRAN database,
* in particular the noble gases, the hydrogen molecule etc
*/
#define ATOMS_OFFSET 100



class Air {
public:
	/** temperature [K]
	*/
	double T ;

	/** pressure [Pa]. Total nominal pressure
	*/
	double Panom;

	struct compon {
		/** The molecule species itself with its line list
		*/
		molecule *molc;

		/** The mixing ratio. This is the roughly percentage of the volume divided through 100, but
		* this latter interpretation is only correct if all components are ideal gases.
		*/
		double volpercent ;

		/** count of molecules per cubic meter, [1/m^3]
		*/
		double mol_m3;

		/** partial pressure [mm Hg]
		*/
		double partp;
	} ;

	/** The array of the molecular constitutents
	*/
	struct compon * mix;

	/** Number (count) of constituents in the \c mix array
	*/
	int mixcnt ;

	/** flag: if true, adjust the densities of the molecules in the dry portion
	* to get the full Air::Panom if all partial pressures are added
	*/
	static bool scale_p ;

	Air(const double temp, const double press) ;

	Air(const double temp, const double press, const double relhum, const double co2, const double o2, const double h2o,
		const double o3, const bool useV, const string dir, int fcount, char *argv[] );

	~Air() ;

#ifdef USE_QOFT
	void Qsum() ;
#endif

	complex<double> suscep(const double lambda) ;



	double magn(const double useV) ;

	double ppmCO2() const ;


	double Pa(double &mols, const bool excludh2o) const ;

	int hash2o(const int molecNo) const ;


private:

	void scaledry(const bool useV) ;

	void scale(const bool useV, const set<int> excl) ;

	/** Mixing ratios of the standard air, all between 0 and 1, ordered along the HITRAN molecule numbers but shifted
	* by one index to start with the C/C++ 0-based notation:
	* index 0 = H2O, 1=CO2, 2=O3, 3=N2O, 4=CO, 5=CH4, 6=O2, 7=NO, 8=SO2, 9=NO2,
	* 10=NH3, 11=HNO3 (already in NO2), 12=OH, 21=N2, ATOMS_OFFSET-1=Ne, Kr, Ar, H2, He
	*/
	static const double volrel[] ;

	/** Standard molecule denominations sorted in HITRAN order
	*/
	static const char *nam[] ;
} ;
