#pragma once

using namespace std ;

/** Wagner and Pruss equation of state of water.
\latexonly
\cite{WagnerJPCR31}
\endlatexonly
*/
class WagnerPruss {
public:
	/** Temperature (Kelvin)
	*/
	double T ;

	/** saturation pressure (Pa)
	*/
	double pSatur ;

	WagnerPruss(double kelvin) ;

	double n(const double humidity) const ;

	double P(const double humidity) const ;

protected:

	double rho(const double humidity) const ;

private:
			// incorporate WAgner J Phys Chem Ref Data, not  23 (1994) but 31 (2002)
			// parts of the Wagner-Pruss tables
	struct tab62aS { int ci; int di; double ti; double ni ; } ;
	static const tab62aS tab62a[]  ;
	struct tab62bS { int di; int ti; double ni; int alphi; int beti; double gami; int epsi ;} ;
	static const tab62bS tab62b[] ;
	struct tab62cS { double ai; double bi; double Bi; double ni; int Ci; int Di; double Ai; double beti ;} ;
	static const tab62cS tab62c[] ;

	static const double R=0.46151805 ;	// kJ/Kg/K equation 6.3
	static const double rhoc= 322e3 ;	// kg/m^3 after (3.2) and (6.2)
	static const double Tc=647.096; // Kelvin equation 6.1
	static const double M= 18.015268 ;	// molar mass grames per mol, p 395

	double tau ;

	double pWPruss() const ;

	double dDeltaddelta(const int i, const double dmin1, const double theta) const ;

	double Phi_delta_r(const double delta) const ;


} ;
