#ifndef WATER_H
#define WATER_H

#include "virial.h"

// parameter for the equation-of-state (or enhancement factor)
// WagnerPruss is J Phys Chem Ref Data 31 p 387, Eq (2.5) and consistent with Table 13.1
enum eos { Fairchild , Virial, WPruss } ;

class water {
public:
	water(double kelvin, enum eos enhanc = Fairchild) ;

	water(double kelvin, virial &v) ;

	water(const water &orig) ;

	~water() ;

	double n(const double humidity) const ;
	double mixrat(const double humidity, const double pres) const ;

protected:

	double nWPruss(const double humidity) const ;

	double nFairchild(const double humidity) const ;

private:
	double T ;
	enum eos equa_of_s ;
	virial * vir ;
} ;

#endif /* WATER_H */
